local FOLDER_NAME, SSA = ...
local version = GetAddOnMetadata(FOLDER_NAME,"Version");
local L = LibStub("AceLocale-3.0"):GetLocale("ShamanAuras", true)
local Auras = LibStub("AceAddon-3.0"):GetAddon("ShamanAuras")

local ele_options

local function GetElementalOptions()
	if not ele_options then
		ele_options = {
			type = "group",
			order = 1,
			name = L["Elemental Auras"],
			desc = L["Auras used by the Elemental specialization"],
			args = {
				desc = {
					order = 0,
					type = "description",
					name = L["Elemental Shaman Auras"],
				},
				show = {
					order = 1,
					name = L["Show Elemental Auras"],
					desc = L["Toggle the display of Elemental Auras"],
					type = "toggle",
					get = function()
						return Auras.db.char.frames.eleGrp;
					end,
					set = function(_, value)
						Auras.db.char.frames.eleGrp = value;
					end,
				},
				MajorAuras = {
					name = L["Major Auras"],
					type = "group",
					order = 2,
					guiInline = true,
					args = {
						AncestralGuidanceEle = {
							order = 1,
							type = "toggle",
							name = L["Ancestral Guidance"],
							get = function() 
								return Auras.db.char.aura[1].AncestralGuidanceEle;
							end,
							set = function(_, value)
								Auras.db.char.aura[1].AncestralGuidanceEle = value
								Auras:UpdateTalents()
							end,
						},
						AscendanceEle = {
							order = 2,
							type = "toggle",
							name = L["Ascendance"],
							get = function() 
								return Auras.db.char.aura[1].AscendanceEle;
							end,
							set = function(_, value)
								Auras.db.char.aura[1].AscendanceEle = value
								Auras:UpdateTalents()
							end,
						},
						EarthShock = {
							order = 3,
							type = "toggle",
							name = L["Earth Shock"],
							get = function()
								return Auras.db.char.aura[1].EarthShock;
							end,
							set = function(_, value)
								Auras.db.char.aura[1].EarthShock = value
								Auras:UpdateTalents()
							end,
						},
						ElementalBlast = {
							order = 4,
							type = "toggle",
							name = L["Elemental Blast"],
							get = function()
								return Auras.db.char.aura[1].ElementalBlast;
							end,
							set = function(_, value)
								Auras.db.char.aura[1].ElementalBlast = value
								Auras:UpdateTalents()
							end,
						},
						ElementalMastery = {
							order = 5,
							type = "toggle",
							name = L["Elemental Mastery"],
							get = function()
								return Auras.db.char.aura[1].ElementalMastery;
							end,
							set = function(_, value)
								Auras.db.char.aura[1].ElementalMastery = value
								Auras:UpdateTalents()
							end,
						},
						FireElemental = {
							order = 6,
							type = "toggle",
							name = L["Fire Elemental"],
							get = function() 
								return Auras.db.char.aura[1].FireElemental;
							end,
							set = function(_, value)
								Auras.db.char.aura[1].FireElemental = value
								Auras:UpdateTalents()
							end,
						},
						FlameShock = {
							order = 7,
							type = "toggle",
							name = L["Flame Shock"],
							get = function()
								return Auras.db.char.aura[1].FlameShock;
							end,
							set = function(_, value)
								Auras.db.char.aura[1].FlameShock = value
								Auras:UpdateTalents()
							end,
						},
						Icefury = {
							order = 8,
							type = "toggle",
							name = L["Icefury"],
							get = function() 
								return Auras.db.char.aura[1].Icefury;
							end,
							set = function(_, value)
								Auras.db.char.aura[1].Icefury = value
								Auras:UpdateTalents()
							end,
						},
						LavaBurst = {
							order = 9,
							type = "toggle",
							name = L["Lava Burst"],
							get = function()
								return Auras.db.char.aura[1].LavaBurst;
							end,
							set = function(_, value)
								Auras.db.char.aura[1].LavaBurst = value
								Auras:UpdateTalents()
							end,
						},
						StormElemental = {
							order = 10,
							type = "toggle",
							name = L["Storm Elemental"],
							get = function() 
								return Auras.db.char.aura[1].StormElemental;
							end,
							set = function(_, value)
								Auras.db.char.aura[1].StormElemental = value
								Auras:UpdateTalents()
							end,
						},
					},
				},
				MinorAuras = {
					name = L["Minor Auras"],
					type = "group",
					order = 3,
					guiInline = true,
					args = {
						AstralShift = {
							order = 1,
							type = "toggle",
							name = L["Astral Shift"],
							get = function()
								return Auras.db.char.aura[1].AstralShiftEle;
							end,
							set = function(_, value)
								Auras.db.char.aura[1].AstralShiftEle = value
								Auras:UpdateTalents()
							end,
						},
						EarthElemental = {
							order = 2,
							type = "toggle",
							name = L["Earth Elemental"],
							get = function()
								return Auras.db.char.aura[1].EarthElemental;
							end,
							set = function(_, value)
								Auras.db.char.aura[1].EarthElemental = value
								Auras:UpdateTalents()
							end,
						},
						EarthgrabTotemEle = {
							order = 3,
							type = "toggle",
							name = L["Earthgrab Totem"],
							get = function()
								return Auras.db.char.aura[1].EarthgrabTotemEle;
							end,
							set = function(_, value)
								Auras.db.char.aura[1].EarthgrabTotemEle = value
								Auras:UpdateTalents()
							end,
						},
						Hex = {
							order = 4,
							type = "toggle",
							name = L["Hex"],
							get = function()
								return Auras.db.char.aura[1].HexEle;
							end,
							set = function(_, value)
								Auras.db.char.aura[1].HexEle = value
								Auras:UpdateTalents()
							end,
						},
						Thunderstorm = {
							order = 5,
							type = "toggle",
							name = L["Thunderstorm"],
							get = function()
								return Auras.db.char.aura[1].Thunderstorm;
							end,
							set = function(_, value)
								Auras.db.char.aura[1].Thunderstorm = value
								Auras:UpdateTalents()
							end,
						},
						LightningSurgeTotemEle = {
							order = 6,
							type = "toggle",
							name = L["Lightning Surge Totem"],
							get = function()
								return Auras.db.char.aura[1].LightningSurgeTotemEle;
							end,
							set = function(_, value)
								Auras.db.char.aura[1].LightningSurgeTotemEle = value
								Auras:UpdateTalents()
							end,
						},
						VoodooTotemEle = {
							order = 7,
							type = "toggle",
							name = L["Voodoo Totem"],
							get = function()
								return Auras.db.char.aura[1].VoodooTotemEle;
							end,
							set = function(_, value)
								Auras.db.char.aura[1].VoodooTotemEle = value
								Auras:UpdateTalents()
							end,
						},
						Windshear = {
							order = 8,
							type = "toggle",
							name = L["Wind Shear"],
							get = function() 
								return Auras.db.char.aura[1].WindShearEle;
							end,
							set = function(_, value)
								Auras.db.char.aura[1].WindShearEle = value
								Auras:UpdateTalents()
							end,
						},
					},
				},
				ProgressBars = {
					name = L["Progress Bars"],
					type = "group",
					order = 4,
					guiInline = true,
					args = {
						MaelstromBarEle = {
							order = 1,
							type = "toggle",
							name = L["Maelstrom Bar"],
							get = function() 
								return Auras.db.char.aura[1].MaelstromBarEle;
							end,
							set = function(_, value)
								Auras.db.char.aura[1].MaelstromBarEle = value
							end,
						},
						IcefuryBar = {
							order = 2,
							type = "toggle",
							name = L["Icefury Bar"],
							get = function() 
								return Auras.db.char.aura[1].IcefuryBar;
							end,
							set = function(_, value)
								Auras.db.char.aura[1].IcefuryBar = value
							end,
						},
						BuffTimerBars = {
							name = L["Buff Duration Timers"],
							type = "group",
							order = 4,
							guiInline = true,
							args = {
								AncestralGuidance = {
									order = 1,
									type = "toggle",
									name = L["Ancestral Guidance"],
									get = function() 
										return Auras.db.char.aura[1].AncestralGuidanceBarEle;
									end,
									set = function(_, value)
										Auras.db.char.aura[1].AncestralGuidanceBarEle = value
									end,
								},
								Ascendance = {
									order = 2,
									type = "toggle",
									name = L["Ascendance"],
									get = function() 
										return Auras.db.char.aura[1].AscendanceBarEle;
									end,
									set = function(_, value)
										Auras.db.char.aura[1].AscendanceBarEle = value
									end,
								},
								AstralShift = {
									order = 3,
									type = "toggle",
									name = L["Astral Shift"],
									get = function() 
										return Auras.db.char.aura[1].AstralShiftBarEle;
									end,
									set = function(_, value)
										Auras.db.char.aura[1].AstralShiftBarEle = value
									end,
								},
								EarthElemental = {
									order = 4,
									type = "toggle",
									name = L["Earth Elemental"],
									get = function() 
										return Auras.db.char.aura[1].EarthElementalBar;
									end,
									set = function(_, value)
										Auras.db.char.aura[1].EarthElementalBar = value;
									end,
								},
								ElementalBlast = {
									order = 5,
									type = "toggle",
									name = L["Elemental Blast"],
									get = function() 
										return Auras.db.char.aura[1].ElementalBlastCritBar;
									end,
									set = function(_, value)
										Auras.db.char.aura[1].ElementalBlastCritBar = value;
										Auras.db.char.aura[1].ElementalBlastHasteBar = value;
										Auras.db.char.aura[1].ElementalBlastMasteryBar = value;
									end,
								},
								FireElemental = {
									order = 6,
									type = "toggle",
									name = L["Fire Elemental"],
									get = function() 
										return Auras.db.char.aura[1].FireElementalBar;
									end,
									set = function(_, value)
										Auras.db.char.aura[1].FireElementalBar = value;
									end,
								},
								StormElemental = {
									order = 7,
									type = "toggle",
									name = L["Storm Elemental"],
									get = function() 
										return Auras.db.char.aura[1].StormElementalBar;
									end,
									set = function(_, value)
										Auras.db.char.aura[1].StormElementalBar = value;
									end,
								},
								
							},
						},
						TotemTimerBars = {
							name = L["Totem Duration Timers"],
							type = "group",
							order = 5,
							guiInline = true,
							args = {
								EarthgrabTotem = {
									order = 1,
									type = "toggle",
									name = L["Earthgrab Totem"],
									get = function() 
										return Auras.db.char.aura[1].EarthgrabTotemBarEle;
									end,
									set = function(_, value)
										Auras.db.char.aura[1].EarthgrabTotemBarEle = value
									end,
								},
								VoodooTotem = {
									order = 2,
									type = "toggle",
									name = L["Voodoo Totem"],
									get = function() 
										return Auras.db.char.aura[1].VoodooTotemBarEle;
									end,
									set = function(_, value)
										Auras.db.char.aura[1].VoodooTotemBarEle = value
									end,
								},
								WindRushTotem = {
									order = 3,
									type = "toggle",
									name = L["Wind Rush Totem"],
									get = function() 
										return Auras.db.char.aura[1].WindRushTotemBarEle;
									end,
									set = function(_, value)
										Auras.db.char.aura[1].WindRushTotemBarEle = value
									end,
								},
								LiquidMagmaTotem = {
									order = 4,
									type = "toggle",
									name = L["Liquid Magma Totem"],
									get = function() 
										return Auras.db.char.aura[1].LiquidMagmaTotemBar;
									end,
									set = function(_, value)
										Auras.db.char.aura[1].LiquidMagmaTotemBar = value
									end,
								},
							},
						},
					},
				},
				TextureAlerts = {
					name = L["Texture Alerts"],
					type = "group",
					order = 5,
					guiInline = true,
					args = {
						TotemMastery = {
							order = 1,
							type = "toggle",
							name = L["Totem Mastery"],
							get = function() 
								return Auras.db.char.aura[1].TotemMastery;
							end,
							set = function(_, value)
								Auras.db.char.aura[1].TotemMastery = value
							end,
						},
						LavaSurge = {
							order = 2,
							type = "toggle",
							name = L["Lava Surge"],
							get = function() 
								return Auras.db.char.aura[1].LavaSurgeEle;
							end,
							set = function(_, value)
								Auras.db.char.aura[1].LavaSurgeEle = value
							end,
						},
						Stormkeeper = {
							order = 3,
							type = "toggle",
							name = L["Stormkeeper"],
							get = function() 
								return Auras.db.char.aura[1].StormkeeperChargeGrp;
							end,
							set = function(_, value)
								Auras.db.char.aura[1].StormkeeperChargeGrp = value
							end,
						},
					},
				},
			}
		}
	end
	return ele_options;
end

local enh_options

local function GetEnhancementOptions()
	if not enh_options then

		enh_options = {
			type = "group",
			order = 1,
			name = L["Enhancement Auras"],
			desc = L["Auras used by the Enhancement specialization"],
			args = {
				desc = {
					order = 0,
					type = "description",
					name = L["Enhancement Shaman Auras"],
				},
				show = {
					order = 1,
					name = L["Show Enhancement Auras"],
					desc = L["Toggle the display of Elemental Auras"],
					type = "toggle",
					get = function()
						return Auras.db.char.frames.eleGrp;
					end,
					set = function(_, value)
						Auras.db.char.frames.eleGrp = value;
					end,
				},
				MajorAuras = {
					name = L["Major Auras"],
					type = "group",
					order = 2,
					guiInline = true,
					args = {
						AscendanceEle = {
							order = 1,
							type = "toggle",
							name = L["Ascendance"],
							get = function() 
								return Auras.db.char.aura[2].AscendanceEnh;
							end,
							set = function(_, value)
								Auras.db.char.aura[2].AscendanceEnh = value
								--Auras:ToggleAuraIcons(1);
								Auras:UpdateTalents()
							end,
						},
						Boulderfist = {
							order = 2,
							type = "toggle",
							name = L["Boulderfist"],
							get = function()
								return Auras.db.char.aura[2].Boulderfist;
							end,
							set = function(_, value)
								Auras.db.char.aura[2].Boulderfist = value
								Auras:UpdateTalents()
							end,
						},
						CrashLightning = {
							order = 3,
							type = "toggle",
							name = L["Crash Lightning"],
							get = function()
								return Auras.db.char.aura[2].CrashLightning;
							end,
							set = function(_, value)
								Auras.db.char.aura[2].CrashLightning = value
								Auras:UpdateTalents()
							end,
						},
						EarthenSpike = {
							order = 4,
							type = "toggle",
							name = L["Earthen Spike"],
							get = function()
								return Auras.db.char.aura[2].EarthenSpike;
							end,
							set = function(_, value)
								Auras.db.char.aura[2].EarthenSpike = value
								Auras:UpdateTalents()
							end,
						},
						FeralLunge = {
							order = 5,
							type = "toggle",
							name = L["Feral Lunge"],
							get = function()
								return Auras.db.char.aura[2].FeralLunge;
							end,
							set = function(_, value)
								Auras.db.char.aura[2].FeralLunge = value
								Auras:UpdateTalents()
							end,
						},
						FeralSpirit = {
							order = 6,
							type = "toggle",
							name = L["Feral Spirit"],
							get = function()
								return Auras.db.char.aura[2].FeralSpirit;
							end,
							set = function(_, value)
								Auras.db.char.aura[2].FeralSpirit = value
								Auras:UpdateTalents()
							end,
						},
						Flametongue = {
							order = 7,
							type = "toggle",
							name = L["Flametongue"],
							get = function()
								return Auras.db.char.aura[2].Flametongue;
							end,
							set = function(_, value)
								Auras.db.char.aura[2].Flametongue = value
								Auras:UpdateTalents()
							end,
						},
						Frostbrand = {
							order = 8,
							type = "toggle",
							name = L["Frostbrand"],
							get = function()
								return Auras.db.char.aura[2].Frostbrand;
							end,
							set = function(_, value)
								Auras.db.char.aura[2].Frostbrand = value
								Auras:UpdateTalents()
							end,
						},
						Stormstrike = {
							order = 9,
							type = "toggle",
							name = L["Stormstrike"],
							get = function()
								return Auras.db.char.aura[2].Stormstrike;
							end,
							set = function(_, value)
								Auras.db.char.aura[2].Stormstrike = value
								Auras:UpdateTalents()
							end,
						},
						Sundering = {
							order = 10,
							type = "toggle",
							name = L["Sundering"],
							get = function()
								return Auras.db.char.aura[2].Sundering;
							end,
							set = function(_, value)
								Auras.db.char.aura[2].Sundering = value
								Auras:UpdateTalents()
							end,
						},
						Windsong = {
							order = 11,
							type = "toggle",
							name = L["Windsong"],
							get = function()
								return Auras.db.char.aura[2].Windsong;
							end,
							set = function(_, value)
								Auras.db.char.aura[2].Windsong = value
								Auras:UpdateTalents()
							end,
						},
					},
				},
				MinorAuras = {
					name = L["Minor Auras"],
					type = "group",
					order = 3,
					guiInline = true,
					args = {
						AstralShiftEnh = {
							order = 1,
							type = "toggle",
							name = L["Astral Shift"],
							get = function()
								return Auras.db.char.aura[2].AstralShiftEnh;
							end,
							set = function(_, value)
								Auras.db.char.aura[2].AstralShiftEnh = value
								Auras:UpdateTalents()
							end,
						},
						EarthgrabTotemEnh = {
							order = 2,
							type = "toggle",
							name = L["Earthgrab Totem"],
							get = function()
								return Auras.db.char.aura[2].EarthgrabTotemEnh;
							end,
							set = function(_, value)
								Auras.db.char.aura[2].EarthgrabTotemEnh = value
								Auras:UpdateTalents()
							end,
						},
						LightningSurgeTotemEnh = {
							order = 3,
							type = "toggle",
							name = L["Lightning Surge Totem"],
							get = function()
								return Auras.db.char.aura[2].LightningSurgeTotemEnh;
							end,
							set = function(_, value)
								Auras.db.char.aura[2].LightningSurgeTotemEnh = value
								Auras:UpdateTalents()
							end,
						},
						Rainfall = {
							order = 4,
							type = "toggle",
							name = L["Rainfall"],
							get = function()
								return Auras.db.char.aura[2].Rainfall;
							end,
							set = function(_, value)
								Auras.db.char.aura[2].Rainfall = value
								Auras:UpdateTalents()
							end,
						},
						SpiritWalk = {
							order = 5,
							type = "toggle",
							name = L["Spirit Walk"],
							get = function()
								return Auras.db.char.aura[2].SpiritWalk;
							end,
							set = function(_, value)
								Auras.db.char.aura[2].SpiritWalk = value
								Auras:UpdateTalents()
							end,
						},
						VoodooTotemEnh = {
							order = 6,
							type = "toggle",
							name = L["Voodoo Totem"],
							get = function()
								return Auras.db.char.aura[2].VoodooTotemEnh;
							end,
							set = function(_, value)
								Auras.db.char.aura[2].VoodooTotemEnh = value
								Auras:UpdateTalents()
							end,
						},
						WindShearEnh = {
							order = 4,
							type = "toggle",
							name = L["Wind Shear"],
							get = function()
								return Auras.db.char.aura[2].WindShearEnh;
							end,
							set = function(_, value)
								Auras.db.char.aura[2].WindShearEnh = value
								Auras:UpdateTalents()
							end,
						},
					},
				},
				ProgressBars = {
					name = L["Progress Bars"],
					type = "group",
					order = 4,
					guiInline = true,
					args = {
						MaelstromBarEnh = {
							order = 1,
							type = "toggle",
							name = L["Maelstrom Bar"],
							get = function() 
								return Auras.db.char.aura[2].MaelstromBarEnh;
							end,
							set = function(_, value)
								Auras.db.char.aura[2].MaelstromBarEnh = value
							end,
						},
						StormstrikeOrbs = {
							order = 2,
							type = "toggle",
							name = L["Stormstrike Lightning Orbs"],
							get = function() 
								return Auras.db.char.aura[2].StormstrikeChargeGrp;
							end,
							set = function(_, value)
								Auras.db.char.aura[2].StormstrikeChargeGrp = value
							end,
						},
						ShowBuffTimersEnh = {
							order = 1,
							type = "toggle",
							name = L["Show Buff Timers"],
							get = function() 
								return Auras.db.char.frames.timerbars.buff[2];
							end,
							set = function(_, value)
								Auras.db.char.frames.timerbars.buff[2] = value
							end,
						},
						ShowAbilityTimersEnh = {
							order = 2,
							type = "toggle",
							name = L["Show Ability Timers"],
							get = function() 
								return Auras.db.char.frames.timerbars.main[2];
							end,
							set = function(_, value)
								Auras.db.char.frames.timerbars.main[2] = value
							end,
						},
						ShowUtilityTimersEnh = {
							order = 3,
							type = "toggle",
							name = L["Show Utility Timers"],
							get = function() 
								return Auras.db.char.frames.timerbars.util[2];
							end,
							set = function(_, value)
								Auras.db.char.frames.timerbars.util[2] = value
							end,
						},
						BuffTimerBars = {
							name = L["Buff Duration Timers"],
							type = "group",
							order = 4,
							guiInline = true,
							args = {
								AscendanceBarEnh = {
									order = 1,
									type = "toggle",
									name = L["Ascendance"],
									get = function() 
										return Auras.db.char.aura[2].AscendanceBarEnh;
									end,
									set = function(_, value)
										Auras.db.char.aura[2].AscendanceBarEnh = value
									end,
								},
								AstralShiftBarEnh = {
									order = 2,
									type = "toggle",
									name = L["Astral Shift"],
									get = function() 
										return Auras.db.char.aura[2].AstralShiftBarEnh;
									end,
									set = function(_, value)
										Auras.db.char.aura[2].AstralShiftBarEnh = value
									end,
								},
								BoulderfistBar = {
									order = 3,
									type = "toggle",
									name = L["Boulderfist"],
									get = function() 
										return Auras.db.char.aura[2].BoulderfistBar;
									end,
									set = function(_, value)
										Auras.db.char.aura[2].BoulderfistBar = value
									end,
								},
								CrashLightningBar = {
									order = 4,
									type = "toggle",
									name = L["Crash Lightning"],
									get = function() 
										return Auras.db.char.aura[2].CrashLightningBar;
									end,
									set = function(_, value)
										Auras.db.char.aura[2].CrashLightningBar = value
									end,
								},
								EarthenSpikeBar = {
									order = 5,
									type = "toggle",
									name = L["Earthen Spike"],
									get = function() 
										return Auras.db.char.aura[2].EarthenSpikeBar;
									end,
									set = function(_, value)
										Auras.db.char.aura[2].EarthenSpikeBar = value
									end,
								},
								FlametongueBar = {
									order = 6,
									type = "toggle",
									name = L["Flametongue"],
									get = function() 
										return Auras.db.char.aura[2].FlametongueBar;
									end,
									set = function(_, value)
										Auras.db.char.aura[2].FlametongueBar = value
									end,
								},
								FrostbrandBar = {
									order = 7,
									type = "toggle",
									name = L["Frostbrand"],
									get = function() 
										return Auras.db.char.aura[2].FrostbrandBar;
									end,
									set = function(_, value)
										Auras.db.char.aura[2].FrostbrandBar = value
									end,
								},
								HexBarEnh = {
									order = 8,
									type = "toggle",
									name = L["Hex"],
									get = function() 
										return Auras.db.char.aura[2].HexBarEnh;
									end,
									set = function(_, value)
										Auras.db.char.aura[2].HexBarEnh = value
									end,
								},
								SpiritWalkBar = {
									order = 9,
									type = "toggle",
									name = L["Spirit Walk"],
									get = function() 
										return Auras.db.char.aura[2].SpiritWalkBar;
									end,
									set = function(_, value)
										Auras.db.char.aura[2].SpiritWalkBar = value
									end,
								},
								WindsongBar = {
									order = 10,
									type = "toggle",
									name = L["Windsong"],
									get = function() 
										return Auras.db.char.aura[2].WindsongBar;
									end,
									set = function(_, value)
										Auras.db.char.aura[2].WindsongBar = value
									end,
								},
							},
						},
						MainTimerBars = {
							name = L["Ability Duration Timers"],
							type = "group",
							order = 5,
							guiInline = true,
							--disabled = function() return (generalSettings.theme == "Graphical") end,
							args = {
								BoulderfistBar = {
									order = 1,
									type = "toggle",
									name = L["Boulderfist"],
									get = function() 
										return Auras.db.char.aura[2].BoulderfistBar;
									end,
									set = function(_, value)
										Auras.db.char.aura[2].BoulderfistBar = value
									end,
								},
								CrashLightningBar = {
									order = 2,
									type = "toggle",
									name = L["Crash Lightning"],
									get = function() 
										return Auras.db.char.aura[2].CrashLightningBar;
									end,
									set = function(_, value)
										Auras.db.char.aura[2].CrashLightningBar = value
									end,
								},
								FlametongueBar = {
									order = 3,
									type = "toggle",
									name = L["Flametongue"],
									get = function() 
										return Auras.db.char.aura[2].FlametongueBar;
									end,
									set = function(_, value)
										Auras.db.char.aura[2].FlametongueBar = value
									end,
								},
								FrostbrandBar = {
									order = 4,
									type = "toggle",
									name = L["Frostbrand"],
									get = function() 
										return Auras.db.char.aura[2].FrostbrandBar;
									end,
									set = function(_, value)
										Auras.db.char.aura[2].FrostbrandBar = value
									end,
								},
								WindsongBar = {
									order = 5,
									type = "toggle",
									name = L["Windsong"],
									get = function() 
										return Auras.db.char.aura[2].WindsongBar;
									end,
									set = function(_, value)
										Auras.db.char.aura[2].WindsongBar = value
									end,
								},
							},
						},
						UtilityTimerBars = {
							name = L["Utility Duration Timers"],
							type = "group",
							order = 6,
							guiInline = true,
							args = {
								EarthgrabTotemBarEnh = {
									order = 1,
									type = "toggle",
									name = L["Earthgrab Totem"],
									get = function() 
										return Auras.db.char.aura[2].EarthgrabTotemBarEnh;
									end,
									set = function(_, value)
										Auras.db.char.aura[2].EarthgrabTotemBarEnh = value
									end,
								},
								VoodooTotemBarEnh = {
									order = 2,
									type = "toggle",
									name = L["Voodoo Totem"],
									get = function() 
										return Auras.db.char.aura[2].VoodooTotemBarEnh;
									end,
									set = function(_, value)
										Auras.db.char.aura[2].VoodooTotemBarEnh = value
									end,
								},
								WindRushTotemBarEnh = {
									order = 3,
									type = "toggle",
									name = L["Wind Rush Totem"],
									get = function() 
										return Auras.db.char.aura[2].WindRushTotemBarEnh;
									end,
									set = function(_, value)
										Auras.db.char.aura[2].WindRushTotemBarEnh = value
									end,
								},
							},
						},
					},
				},
			}
		}
	end
	return enh_options;
end

local resto_options

local function GetRestorationOptions()
	if not resto_options then
		--local sharedGrp = SSA.SharedGrp;
		resto_options = {
			type = "group",
			order = 1,
			name = L["Restoration Auras"],
			desc = L["Auras used by the Restoration specialization"],
			args = {
				desc = {
					order = 0,
					type = "description",
					name = L["Restoration Shaman Auras"],
				},
				show = {
					order = 1,
					name = L["Show Restoration Auras"],
					desc = L["Toggle the display of Elemental Auras"],
					type = "toggle",
					get = function()
						return Auras.db.char.frames.eleGrp;
					end,
					set = function(_, value)
						Auras.db.char.frames.eleGrp = value;
					end,
				},
				MajorAuras = {
					name = L["Major Auras"],
					type = "group",
					order = 2,
					guiInline = true,
					args = {
						AncestralGuidanceRes = {
							order = 1,
							type = "toggle",
							name = L["Ancestral Guidance"],
							get = function() 
								return Auras.db.char.aura[3].AncestralGuidanceRes;
							end,
							set = function(_, value)
								Auras.db.char.aura[3].AncestralGuidanceRes = value
								Auras:UpdateTalents()
							end,
						},
						AscendanceRes = {
							order = 2,
							type = "toggle",
							name = L["Ascendance"],
							get = function() 
								return Auras.db.char.aura[3].AscendanceRes;
							end,
							set = function(_, value)
								Auras.db.char.aura[3].AscendanceRes = value
								Auras:UpdateTalents()
							end,
						},
						CloudburstTotem = {
							order = 3,
							type = "toggle",
							name = L["Cloudburst Totem"],
							get = function() 
								return Auras.db.char.aura[3].CloudburstTotem;
							end,
							set = function(_, value)
								Auras.db.char.aura[3].CloudburstTotem = value
								Auras:UpdateTalents()
							end,
						},
						HealingRain = {
							order = 4,
							type = "toggle",
							name = L["Healing Rain"],
							get = function()
								return Auras.db.char.aura[3].HealingRain;
							end,
							set = function(_, value)
								Auras.db.char.aura[3].HealingRain = value
								Auras:UpdateTalents()
							end,
						},
						HealingStreamTotem = {
							order = 5,
							type = "toggle",
							name = L["Healing Stream Totem"],
							get = function() 
								return Auras.db.char.aura[3].HealingStreamTotem;
							end,
							set = function(_, value)
								Auras.db.char.aura[3].HealingStreamTotem = value
								Auras:UpdateTalents()
							end,
						},
						HealingTideTotem = {
							order = 6,
							type = "toggle",
							name = L["Healing Tide Totem"],
							get = function() 
								return Auras.db.char.aura[3].HealingTideTotem;
							end,
							set = function(_, value)
								Auras.db.char.aura[3].HealingTideTotem = value
								Auras:UpdateTalents()
							end,
						},
						Riptide = {
							order = 7,
							type = "toggle",
							name = L["Riptide"],
							get = function()
								return Auras.db.char.aura[3].Riptide;
							end,
							set = function(_, value)
								Auras.db.char.aura[3].Riptide = value
								Auras:UpdateTalents()
							end,
						},
						UnleashLife = {
							order = 8,
							type = "toggle",
							name = L["Unleash Life"],
							get = function()
								return Auras.db.char.aura[3].UnleashLife;
							end,
							set = function(_, value)
								Auras.db.char.aura[3].UnleashLife = value
								Auras:UpdateTalents()
							end,
						},
						SpiritLinkTotem = {
							order = 9,
							type = "toggle",
							name = L["Spirit Link Totem"],
							get = function() 
								return Auras.db.char.aura[3].SpiritLinkTotem;
							end,
							set = function(_, value)
								Auras.db.char.aura[3].SpiritLinkTotem = value
								Auras:UpdateTalents()
							end,
						},
						Wellspring = {
							order = 10,
							type = "toggle",
							name = L["Wellspring"],
							get = function() 
								return Auras.db.char.aura[3].Wellspring;
							end,
							set = function(_, value)
								Auras.db.char.aura[3].Wellspring = value
								Auras:UpdateTalents()
							end,
						},
						WindRushTotemRes = {
							order = 11,
							type = "toggle",
							name = L["Wind Rush Totem"],
							get = function() 
								return Auras.db.char.aura[3].WindRushTotemRes;
							end,
							set = function(_, value)
								Auras.db.char.aura[3].WindRushTotemRes = value
								Auras:UpdateTalents()
							end,
						},
					},
				},
				MinorAuras = {
					name = L["Minor Auras"],
					type = "group",
					order = 3,
					guiInline = true,
					args = {
						AstralShiftRes = {
							order = 1,
							type = "toggle",
							name = L["Astral Shift"],
							get = function()
								return Auras.db.char.aura[3].AstralShiftRes;
							end,
							set = function(_, value)
								Auras.db.char.aura[3].AstralShiftRes = value
								Auras:UpdateTalents()
							end,
						},
						EarthgrabTotemRes = {
							order = 2,
							type = "toggle",
							name = L["Earthgrab Totem"],
							get = function() 
								return Auras.db.char.aura[3].EarthgrabTotemRes;
							end,
							set = function(_, value)
								Auras.db.char.aura[3].EarthgrabTotemRes = value
								Auras:UpdateTalents()
							end,
						},
						FlameShockRes = {
							order = 3,
							type = "toggle",
							name = L["Flame Shock"],
							get = function() 
								return Auras.db.char.aura[3].FlameShockRes;
							end,
							set = function(_, value)
								Auras.db.char.aura[3].FlameShockRes = value
								Auras:UpdateTalents()
							end,
						},
						GustWindRes = {
							order = 4,
							type = "toggle",
							name = L["Gust of Wind"],
							get = function() 
								return Auras.db.char.aura[3].GustWindRes;
							end,
							set = function(_, value)
								Auras.db.char.aura[3].GustWindRes = value
								Auras:UpdateTalents()
							end,
						},
						LavaBurstRes = {
							order = 5,
							type = "toggle",
							name = L["Lava Burst"],
							get = function() 
								return Auras.db.char.aura[3].LavaBurstRes;
							end,
							set = function(_, value)
								Auras.db.char.aura[3].LavaBurstRes = value
								Auras:UpdateTalents()
							end,
						},
						LightningSurgeTotemRes = {
							order = 6,
							type = "toggle",
							name = L["Lightning Surge Totem"],
							get = function() 
								return Auras.db.char.aura[3].LightningSurgeTotemRes;
							end,
							set = function(_, value)
								Auras.db.char.aura[3].LightningSurgeTotemRes = value
								Auras:UpdateTalents()
							end,
						},
						PurifySpirit = {
							order = 7,
							type = "toggle",
							name = L["Purify Spirit"],
							get = function() 
								return Auras.db.char.aura[3].PurifySpirit;
							end,
							set = function(_, value)
								Auras.db.char.aura[3].PurifySpirit = value
								Auras:UpdateTalents()
							end,
						},
						SpiritwalkersGrace = {
							order = 8,
							type = "toggle",
							name = L["Spiritwalker's Grace"],
							get = function() 
								return Auras.db.char.aura[3].SpiritwalkersGrace;
							end,
							set = function(_, value)
								Auras.db.char.aura[3].SpiritwalkersGrace = value
								Auras:UpdateTalents()
							end,
						},
						VoodooTotemRes = {
							order = 9,
							type = "toggle",
							name = L["Voodoo Totem"],
							get = function() 
								return Auras.db.char.aura[3].VoodooTotemRes;
							end,
							set = function(_, value)
								Auras.db.char.aura[3].VoodooTotemRes = value
								Auras:UpdateTalents()
							end,
						},
						WindShearRes = {
							order = 10,
							type = "toggle",
							name = L["Wind Shear"],
							get = function() 
								return Auras.db.char.aura[3].WindShearRes;
							end,
							set = function(_, value)
								Auras.db.char.aura[3].WindShearRes = value
								Auras:UpdateTalents()
							end,
						},
					},
				},
				ProgressBars = {
					name = L["Progress Bars"],
					type = "group",
					order = 4,
					guiInline = true,
					args = {
						BuffTimerBars = {
							name = L["Buff Duration Timers"],
							type = "group",
							order = 1,
							guiInline = true,
							args = {
								AncestralGuidanceBarRes = {
									order = 1,
									type = "toggle",
									name = L["Ancestral Guidance"],
									get = function() 
										return Auras.db.char.aura[3].AncestralGuidanceBarRes;
									end,
									set = function(_, value)
										Auras.db.char.aura[3].AncestralGuidanceBarRes = value
									end,
								},
								AscendanceBarRes = {
									order = 2,
									type = "toggle",
									name = L["Ascendance"],
									get = function() 
										return Auras.db.char.aura[3].AscendanceBarRes;
									end,
									set = function(_, value)
										Auras.db.char.aura[3].AscendanceBarRes = value
									end,
								},
								AstralShiftBarRes = {
									order = 3,
									type = "toggle",
									name = L["Astral Shift"],
									get = function() 
										return Auras.db.char.aura[3].AstralShiftBarRes;
									end,
									set = function(_, value)
										Auras.db.char.aura[3].AstralShiftBarRes = value
									end,
								},
								BloodlustBarRes = {
									order = 4,
									type = "toggle",
									name = L["Bloodlust"],
									get = function() 
										return Auras.db.char.aura[3].BloodlustBarRes;
									end,
									set = function(_, value)
										Auras.db.char.aura[3].BloodlustBarRes = value;
									end,
								},
								SpiritwalkersGraceBar = {
									order = 5,
									type = "toggle",
									name = L["Elemental Blast"],
									get = function() 
										return Auras.db.char.aura[3].SpiritwalkersGraceBar;
									end,
									set = function(_, value)
										Auras.db.char.aura[3].SpiritwalkersGraceBar = value;
									end,
								},
								UnleashLifeBar = {
									order = 6,
									type = "toggle",
									name = L["Fire Elemental"],
									get = function() 
										return Auras.db.char.aura[3].UnleashLifeBar;
									end,
									set = function(_, value)
										Auras.db.char.aura[3].UnleashLifeBar = value;
									end,
								},								
							},
						},
						TotemTimerBars = {
							name = L["Totem Duration Timers"],
							type = "group",
							order = 2,
							guiInline = true,
							args = {
								AncestralProtectionTotemBar = {
									order = 1,
									type = "toggle",
									name = L["Ancestral Protection Totem"],
									get = function() 
										return Auras.db.char.aura[3].AncestralProtectionTotemBar;
									end,
									set = function(_, value)
										Auras.db.char.aura[3].AncestralProtectionTotemBar = value
									end,
								},
								CloudburstTotemBar = {
									order = 2,
									type = "toggle",
									name = L["Cloudburst Totem"],
									get = function() 
										return Auras.db.char.aura[3].CloudburstTotemBar;
									end,
									set = function(_, value)
										Auras.db.char.aura[3].CloudburstTotemBar = value
									end,
								},
								EarthenShieldTotemBar = {
									order = 3,
									type = "toggle",
									name = L["Earthen Shield Totem"],
									get = function() 
										return Auras.db.char.aura[3].EarthenShieldTotemBar;
									end,
									set = function(_, value)
										Auras.db.char.aura[3].EarthenShieldTotemBar = value
									end,
								},
								EarthgrabTotemBarRes = {
									order = 4,
									type = "toggle",
									name = L["Earthgrab Totem"],
									get = function() 
										return Auras.db.char.aura[3].EarthgrabTotemBarRes;
									end,
									set = function(_, value)
										Auras.db.char.aura[3].EarthgrabTotemBarRes = value
									end,
								},
								HealingStreamTotemBar = {
									order = 5,
									type = "toggle",
									name = L["Healing Stream Totem"],
									get = function() 
										return Auras.db.char.aura[3].HealingStreamTotemBar;
									end,
									set = function(_, value)
										Auras.db.char.aura[3].HealingStreamTotemBar = value
									end,
								},
								HealingTideTotemBar = {
									order = 6,
									type = "toggle",
									name = L["Healing Tide Totem"],
									get = function() 
										return Auras.db.char.aura[3].HealingTideTotemBar;
									end,
									set = function(_, value)
										Auras.db.char.aura[3].HealingTideTotemBar = value
									end,
								},
								SpiritLinkTotemBar = {
									order = 7,
									type = "toggle",
									name = L["Spirit Link Totem"],
									get = function() 
										return Auras.db.char.aura[3].SpiritLinkTotemBar;
									end,
									set = function(_, value)
										Auras.db.char.aura[3].SpiritLinkTotemBar = value
									end,
								},
								VoodooTotemBarRes = {
									order = 8,
									type = "toggle",
									name = L["Voodoo Totem"],
									get = function() 
										return Auras.db.char.aura[3].VoodooTotemBarRes;
									end,
									set = function(_, value)
										Auras.db.char.aura[3].VoodooTotemBarRes = value
									end,
								},
								WindRushTotemBarRes = {
									order = 9,
									type = "toggle",
									name = L["Wind Rush Totem"],
									get = function() 
										return Auras.db.char.aura[3].WindRushTotemBarRes;
									end,
									set = function(_, value)
										Auras.db.char.aura[3].WindRushTotemBarRes = value
									end,
								},
							},
						},
					},
				},
			}
		}
	end
	return resto_options;
end

local settings_options

local function GetSettingsOptions()
	if not settings_options then
		
		settings_options = {
			type = "group",
			order = 1,
			name = L["Settings"],
			desc = L["Advanced customization options"],
			args = {
				EleSettings = {
					name = L["Elemental"],
					type = "group",
					order = 1,
					args = {
						FreeMoveEle = {
							order = 1,
							type = "execute",
							name = L["Move Elemental Auras"],
							disabled = false,
							func = function()
								Auras:InitMoveAuraGroups(SSA.AuraObjectsEle,"Ele")
							end,
						},
						ResetEle = {
							order = 2,
							type = "execute",
							name = L["Reset Elemental Auras"],
							disabled = false,
							func = function()
								Auras:ResetAuraGroups(Auras.db.char.frames.defaultPos.eleGrp,Auras.db.char.frames.eleGrp)
							end,
						},
						MaelstromAnim = {
							order = 3,
							type = "toggle",
							name = L["Maelstrom Lightning"],
							get = function() 
								return Auras.db.char.triggers.ele.MaelstromAnim;
							end,
							set = function(_, value)
								if (value == false) then
									settings_options.args.EleSettings.args.EleTriggers.args.EarthShock.disabled = true;
								else
									settings_options.args.EleSettings.args.EleTriggers.args.EarthShock.disabled = false;
								end
								Auras.db.char.triggers.ele.MaelstromAnim = value
							end,
						},
						EleTriggers = {
							name = L["Aura Settings"],
							type = "group",
							order = 4,
							guiInline = true,
							args = {
								OoCAlpha = {
									order = 1,
									type = "range",
									name = L["Out of Combat Alpha"],
									desc = L["Determines how opaque or transparent the auras will appear when out of combat"],
									min = 0,
									max = 1,
									step = 0.1,
									bigStep = 0.1,
									disabled = false,
									get = function() return Auras.db.char.triggers.ele.OoCAlpha end,
									set = function(_, value)
										Auras.db.char.triggers.ele.OoCAlpha = value
									end,
								},
								OoRColor = {
									type = "color",
									order = 2,
									name = L["Our of Range Color"],
									desc = L["Determines the color of harmful auras will appear when out of range"],
									hasAlpha = true,
									get = function(info)
										return Auras.db.char.triggers.ele.OoRColor.r, Auras.db.char.triggers.ele.OoRColor.g, Auras.db.char.triggers.ele.OoRColor.b, Auras.db.char.triggers.ele.OoRColor.a
									end,
									set = function(info, r, g, b, a)
										Auras.db.char.triggers.ele.OoRColor.r = r
										Auras.db.char.triggers.ele.OoRColor.g = g
										Auras.db.char.triggers.ele.OoRColor.b = b
										Auras.db.char.triggers.ele.OoRColor.a = a
									end,
								},
								EarthShock = {
									order = 3,
									type = "range",
									name = L["Maelstrom Trigger"],
									desc = L["The amount of Maelstrom accumulated at which the \"Lightning\" animation will appear"],
									min = 50,
									max = 100,
									step = 5,
									bigStep = 5,
									disabled = false,
									get = function() return Auras.db.char.triggers.ele.maelstrom end,
									set = function(_, value)
										Auras.db.char.triggers.ele.maelstrom = value
									end,
								},
								FlameShock = {
									order = 4,
									type = "range",
									name = L["Flame Shock"],
									desc = L["The amount of seconds remaining when the \"Glow\" animation will appear"],
									min = 5,
									max = 15,
									step = 1,
									bigStep = 1,
									get = function() return Auras.db.char.triggers.ele.flameShock end,
									set = function(_, value)
										Auras.db.char.triggers.ele.flameShock = value
									end,
								},
								TotemMastery = {
									order = 5,
									type = "range",
									name = L["Totem Mastery"],
									desc = L["The amount of seconds remaining when the Totem Mastery texture will appear"],
									min = 5,
									max = 30,
									step = 1,
									bigStep = 1,
									get = function() return Auras.db.char.triggers.ele.totemMastery end,
									set = function(_, value)
										Auras.db.char.triggers.ele.totemMastery = value
									end,
								},
							},
						},
						ResetEleTriggers = {
							order = 5,
							type = "execute",
							name = L["Reset Settings Values"],
							disabled = false,
							func = function()
								Auras.db.char.triggers.ele.MaelstromAnim = Auras.db.char.triggers.default.ele.MaelstromAnim
								Auras.db.char.triggers.ele.maelstrom = Auras.db.char.triggers.default.ele.maelstrom
								Auras.db.char.triggers.ele.flameShock = Auras.db.char.triggers.default.ele.flameShock
								Auras.db.char.triggers.ele.totemMastery = Auras.db.char.triggers.default.ele.totemMastery
								Auras.db.char.triggers.ele.OoCAlpha = Auras.db.char.triggers.default.ele.OoCAlpha
								Auras.db.char.triggers.ele.OoRColor.r = Auras.db.char.triggers.default.ele.OoRColor.r
								Auras.db.char.triggers.ele.OoRColor.g = Auras.db.char.triggers.default.ele.OoRColor.g
								Auras.db.char.triggers.ele.OoRColor.b = Auras.db.char.triggers.default.ele.OoRColor.b
								Auras.db.char.triggers.ele.OoRColor.a = Auras.db.char.triggers.default.ele.OoRColor.a
							end,
						},
					},
				},
				EnhSettings = {
					name = L["Enhancement"],
					type = "group",
					order = 2,
					args = {
						FreeMoveEnh = {
							order = 1,
							type = "execute",
							name = L["Move Enhancement Auras"],
							disabled = false,
							func = function()
								Auras:InitMoveAuraGroups(SSA.AuraObjectsEnh,"Enh")
							end,
						},
						ResetEnh = {
							order = 2,
							type = "execute",
							name = L["Reset Enhancement Auras"],
							disabled = false,
							func = function()
								Auras:ResetAuraGroups(Auras.db.char.frames.defaultPos.enhGrp,Auras.db.char.frames.enhGrp)
							end,
						},
						EnhTriggers = {
							name = L["Aura Settings"],
							type = "group",
							order = 3,
							guiInline = true,
							args = {
								OoCAlpha = {
									order = 1,
									type = "range",
									name = L["Out of Combat Alpha"],
									desc = L["Determines how opaque or transparent the auras will appear when out of combat"],
									min = 0,
									max = 1,
									step = 0.1,
									bigStep = 0.1,
									disabled = false,
									get = function() return Auras.db.char.triggers.enh.OoCAlpha end,
									set = function(_, value)
										Auras.db.char.triggers.enh.OoCAlpha = value
									end,
								},
								OoRColor = {
									type = "color",
									order = 2,
									name = L["Our of Range Color"],
									desc = L["Determines the color of harmful auras will appear when out of range"],
									hasAlpha = true,
									get = function(info)
										return Auras.db.char.triggers.enh.OoRColor.r, Auras.db.char.triggers.enh.OoRColor.g, Auras.db.char.triggers.enh.OoRColor.b, Auras.db.char.triggers.enh.OoRColor.a
									end,
									set = function(info, r, g, b, a)
										Auras.db.char.triggers.enh.OoRColor.r = r
										Auras.db.char.triggers.enh.OoRColor.g = g
										Auras.db.char.triggers.enh.OoRColor.b = b
										Auras.db.char.triggers.enh.OoRColor.a = a
									end,
								},
							},
						},
						ResetEnhTriggers = {
							order = 4,
							type = "execute",
							name = L["Reset Settings Values"],
							disabled = false,
							func = function()
								Auras.db.char.triggers.enh.OoCAlpha = Auras.db.char.triggers.default.enh.OoCAlpha
								Auras.db.char.triggers.enh.OoRColor.r = Auras.db.char.triggers.default.enh.OoRColor.r
								Auras.db.char.triggers.enh.OoRColor.g = Auras.db.char.triggers.default.enh.OoRColor.g
								Auras.db.char.triggers.enh.OoRColor.b = Auras.db.char.triggers.default.enh.OoRColor.b
								Auras.db.char.triggers.enh.OoRColor.a = Auras.db.char.triggers.default.enh.OoRColor.a
							end,
						},
					},
				},
				ResSettings = {
					name = L["Restoration"],
					type = "group",
					order = 3,
					args = {
						FreeMoveRes = {
							order = 1,
							type = "execute",
							name = L["Move Restoration Auras"],
							disabled = false,
							func = function()
								Auras:InitMoveAuraGroups(SSA.AuraObjectsRes,"Res")
							end,
						},
						ResetRes = {
							order = 2,
							type = "execute",
							name = L["Reset Restoration Auras"],
							disabled = false;
							func = function()
								Auras:ResetAuraGroups(Auras.db.char.frames.defaultPos.resGrp,Auras.db.char.frames.resGrp)
							end,
						},
						ResTriggers = {
							name = L["Aura Settings"],
							type = "group",
							order = 3,
							guiInline = true,
							args = {
								OoCAlpha = {
									order = 1,
									type = "range",
									name = L["Out of Combat Alpha"],
									desc = L["Determines how opaque or transparent the auras will appear when out of combat"],
									min = 0,
									max = 1,
									step = 0.1,
									bigStep = 0.1,
									disabled = false,
									get = function() return Auras.db.char.triggers.res.OoCAlpha end,
									set = function(_, value)
										Auras.db.char.triggers.res.OoCAlpha = value
									end,
								},
								OoRColor = {
									type = "color",
									order = 2,
									name = L["Our of Range Color"],
									desc = L["Determines the color of harmful auras will appear when out of range"],
									hasAlpha = true,
									get = function(info)
										return Auras.db.char.triggers.res.OoRColor.r, Auras.db.char.triggers.res.OoRColor.g, Auras.db.char.triggers.res.OoRColor.b, Auras.db.char.triggers.res.OoRColor.a
									end,
									set = function(info, r, g, b, a)
										Auras.db.char.triggers.res.OoRColor.r = r
										Auras.db.char.triggers.res.OoRColor.g = g
										Auras.db.char.triggers.res.OoRColor.b = b
										Auras.db.char.triggers.res.OoRColor.a = a
									end,
								},
							},
						},
						ResetResTriggers = {
							order = 4,
							type = "execute",
							name = L["Reset Settings Values"],
							disabled = false,
							func = function()
								Auras.db.char.triggers.res.OoCAlpha = Auras.db.char.triggers.default.res.OoCAlpha
								Auras.db.char.triggers.res.OoRColor.r = Auras.db.char.triggers.default.res.OoRColor.r
								Auras.db.char.triggers.res.OoRColor.g = Auras.db.char.triggers.default.res.OoRColor.g
								Auras.db.char.triggers.res.OoRColor.b = Auras.db.char.triggers.default.res.OoRColor.b
								Auras.db.char.triggers.res.OoRColor.a = Auras.db.char.triggers.default.res.OoRColor.a
							end,
						},
					},
				},
			}
		}
	end
	return settings_options;
end


function Auras:SetupOptions()
	local ACFG = LibStub("AceConfig-3.0")
	ACFG:RegisterOptionsTable("ShamanAuras Elemental Auras", GetElementalOptions)
	ACFG:RegisterOptionsTable("ShamanAuras Enhancement Auras", GetEnhancementOptions)
	ACFG:RegisterOptionsTable("ShamanAuras Restoration Auras", GetRestorationOptions)
	ACFG:RegisterOptionsTable("ShamanAuras Settings", GetSettingsOptions)

	local ACD = LibStub("AceConfigDialog-3.0")
	ACD:AddToBlizOptions("ShamanAuras Elemental Auras", L["Elemental Auras"], "ShamanAuras")
	ACD:AddToBlizOptions("ShamanAuras Enhancement Auras", L["Enhancement Auras"], "ShamanAuras")
	ACD:AddToBlizOptions("ShamanAuras Restoration Auras", L["Restoration Auras"], "ShamanAuras")
	ACD:AddToBlizOptions("ShamanAuras Settings", L["Settings"], "ShamanAuras")
end

InterfaceOptionsFrame:HookScript("OnShow",function(self)
	local spec = GetSpecialization();
	local settings = GetSettingsOptions();
	settings.args.EleSettings.args.FreeMoveEle.disabled = true;
	settings.args.EleSettings.args.FreeMoveEle.name = "|cFF666666"..L["Move Elemental Auras"].."|r";
	settings.args.EleSettings.args.ResetEle.disabled = true;
	settings.args.EleSettings.args.ResetEle.name = "|cFF666666"..L["Reset Elemental Auras"].."|r";
	settings.args.EnhSettings.args.FreeMoveEnh.disabled = true;
	settings.args.EnhSettings.args.FreeMoveEnh.name = "|cFF666666"..L["Move Enhancement Auras"].."|r";
	settings.args.EnhSettings.args.ResetEnh.disabled = true;
	settings.args.EnhSettings.args.ResetEnh.name = "|cFF666666"..L["Reset Enhancement Auras"].."|r";
	settings.args.ResSettings.args.FreeMoveRes.disabled = true;
	settings.args.ResSettings.args.FreeMoveRes.name = "|cFF666666"..L["Move Restoration Auras"].."|r";
	settings.args.ResSettings.args.ResetRes.disabled = true;
	settings.args.ResSettings.args.ResetRes.name = "|cFF666666"..L["Reset Restoration Auras"].."|r";
	
	if (spec == 1) then
		settings.args.EleSettings.args.FreeMoveEle.disabled = false;
		settings.args.EleSettings.args.FreeMoveEle.name = "|cFFFFCC00"..L["Move Elemental Auras"].."|r";
		settings.args.EleSettings.args.ResetEle.disabled = false;
		settings.args.EleSettings.args.ResetEle.name = "|cFFFFCC00"..L["Reset Elemental Auras"].."|r";
	elseif (spec == 2) then
		settings.args.EnhSettings.args.FreeMoveEnh.disabled = false;
		settings.args.EnhSettings.args.FreeMoveEnh.name = "|cFFFFCC00"..L["Move Enhancement Auras"].."|r";
		settings.args.EnhSettings.args.ResetEnh.disabled = false;
		settings.args.EnhSettings.args.ResetEnh.name = "|cFFFFCC00"..L["Reset Enhancement Auras"].."|r";
	elseif (spec == 3) then
		settings.args.ResSettings.args.FreeMoveRes.disabled = false;
		settings.args.ResSettings.args.FreeMoveRes.name = "|cFFFFCC00"..L["Move Restoration Auras"].."|r";
		settings.args.ResSettings.args.ResetRes.disabled = false;
		settings.args.ResSettings.args.ResetRes.name = "|cFFFFCC00"..L["Reset Restoration Auras"].."|r";
	end
end);